@@ -17,6 +17,11 @@ void lqt_set_video_parameter(quicktime_t *file,int stream, char *key,void *value
 int lqt_set_fiel(quicktime_t *, int, int, int);
 int lqt_get_fiel(quicktime_t *, int, int *, int *);
 
+int lqt_get_pixel_aspect(quicktime_t *file, int track, int * pixel_width,
+                         int * pixel_height);
+int lqt_set_pixel_aspect(quicktime_t *file, int track, int pixel_width,
+                         int pixel_height);
+  
 int lqt_get_codec_api_version();
 
 /***********************************************
