@@ -49,8 +49,10 @@ extern "C" {
 #define QUICKTIME_YUV420  "yv12"
 /* 8 bit Planar YUV 4:1:1 */
 #define QUICKTIME_YUV411  "y411"
-/* 8 bit Packed YUV 4:2:2 */
+/* 8 bit Packed full-range (not video) YUV 4:2:2 */
 #define QUICKTIME_YUV422 "yuv2"
+/* 8 bit Packed YUV (video range) 4:2:2 */
+#define QUICKTIME_2VUY "2vuy"
 /* 8 bit Planar YUV 4:4:4 */
 #define QUICKTIME_YUV444  "v308"
 /* 8 bit Planar YUVA 4:4:4:4 */
@@ -202,13 +204,8 @@ int quicktime_set_video_position(quicktime_t *file, int64_t frame, int track);
 /* ========================== Access to raw data follows. */
 /* write data for one quicktime track */
 /* the user must handle conversion to the channels in this track */
-int quicktime_write_audio(quicktime_t *file, char *audio_buffer, long samples, int track);
-int quicktime_write_frame(quicktime_t *file, unsigned char *video_buffer, int64_t bytes, int track);
-
-/* Read an entire chunk. */
-/* read the number of bytes starting at the byte_start in the specified chunk */
-/* You must provide enough space to store the chunk. */
-int quicktime_read_chunk(quicktime_t *file, char *output, int track, int64_t chunk, int64_t byte_start, int64_t byte_len);
+int quicktime_write_audio(quicktime_t *file, uint8_t *audio_buffer, long samples, int track);
+int quicktime_write_frame(quicktime_t *file, uint8_t *video_buffer, int64_t bytes, int track);
 
 /* read raw data */
 long quicktime_read_audio(quicktime_t *file, char *audio_buffer, long samples, int track);
