@@ -10,7 +10,7 @@
 
 typedef struct
 {
-	char *work_buffer;
+	uint8_t *work_buffer;
 	long buffer_size;
 
 /* Decode specific stuff */
@@ -119,6 +119,16 @@ static int quicktime_decode_rawaudio(quicktime_t *file,
             }
 
           codec->decode_block_align = track_map->channels * bits / 8;
+
+          /* Read first chunk */
+
+          codec->decode_buffer_size = lqt_read_audio_chunk(file,
+                                                           track, file->atracks[track].current_chunk,
+                                                           &(codec->decode_buffer),
+                                                           &(codec->decode_buffer_alloc));
+          if(codec->decode_buffer_size <= 0)
+            return 0;
+          codec->decode_buffer_ptr = codec->decode_buffer;
           }
         
         if(file->atracks[track].current_position != file->atracks[track].last_position)
@@ -185,12 +195,10 @@ static int quicktime_decode_rawaudio(quicktime_t *file,
                                                                &(codec->decode_buffer_alloc));
               
               if(codec->decode_buffer_size <= 0)
-                return 0;
+                break;
               codec->decode_buffer_ptr = codec->decode_buffer;
               }
 
-            if(codec->decode_buffer_size <= 0)
-              return 0;
             codec->decode_sample_buffer_size = codec->decode_buffer_size / codec->decode_block_align;
             if(codec->decode_sample_buffer_size > SAMPLES_PER_BLOCK)
               {
