@@ -263,6 +263,17 @@ static int quicktime_decode_ulaw(quicktime_t *file,
           ulaw_init_ulawtoint16(file, track);
           
           codec->decode_block_align = track_map->channels;
+
+          /* Read first chunk */
+          
+          codec->decode_buffer_size = lqt_read_audio_chunk(file,
+                                                           track, file->atracks[track].current_chunk,
+                                                           &(codec->decode_buffer),
+                                                           &(codec->decode_buffer_alloc));
+              
+          if(codec->decode_buffer_size <= 0)
+            return 0;
+          codec->decode_buffer_ptr = codec->decode_buffer;
           }
         
         if(file->atracks[track].current_position != file->atracks[track].last_position)
@@ -299,7 +310,7 @@ static int quicktime_decode_ulaw(quicktime_t *file,
           if(samples_to_skip < 0)
             {
             fprintf(stderr, "ulaw: Cannot skip %d samples backwards %lld %ld\n", samples_to_skip,
-                    file->atracks[track].current_position, file->atracks[track].last_position);
+                    (long long)(file->atracks[track].current_position), file->atracks[track].last_position);
             samples_to_skip = 0;
             }
           codec->decode_buffer_ptr = codec->decode_buffer + samples_to_skip * codec->decode_block_align;
@@ -328,12 +339,10 @@ static int quicktime_decode_ulaw(quicktime_t *file,
                                                                &(codec->decode_buffer_alloc));
               
               if(codec->decode_buffer_size <= 0)
-                return 0;
+                break;
               codec->decode_buffer_ptr = codec->decode_buffer;
               }
 
-            if(!codec->decode_buffer_size)
-              break;
             
             codec->decode_sample_buffer_size = codec->decode_buffer_size / codec->decode_block_align;
             if(codec->decode_sample_buffer_size > SAMPLES_PER_BLOCK)
