@@ -1,23 +1,21 @@
 /* 
-   ffmpeg.c (C) Justin Schoeman 2002 (justin@suntiger.ee.up.ac.za)
-   Based entirely upon qtpng.c from libquicktime 
-   (http://libquicktime.sf.net).
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-    
-*/
+ * video.c (C) Justin Schoeman 2002 (justin@suntiger.ee.up.ac.za)
+ * Based entirely upon qtpng.c from libquicktime 
+ * (http://libquicktime.sf.net).
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ */
 
 
 #include "config.h"
@@ -744,9 +742,14 @@ int lqt_ffmpeg_encode_video(quicktime_t *file, unsigned char **row_pointers,
 	if(!codec->com.init_enc) {
                 codec->com.ffcodec_enc = avcodec_alloc_context();
                 codec->frame = avcodec_alloc_frame();
+#if LIBAVCODEC_BUILD >= 4754
+                codec->com.ffcodec_enc->time_base.den = lqt_video_time_scale(file, track);
+                codec->com.ffcodec_enc->time_base.num = lqt_frame_duration(file, track, NULL);
+#else
 		codec->com.ffcodec_enc->frame_rate =
                   (int)(quicktime_frame_rate(file, track) * (float)DEFAULT_FRAME_RATE_BASE);
                 codec->com.ffcodec_enc->frame_rate_base = DEFAULT_FRAME_RATE_BASE;
+#endif
 		codec->com.ffcodec_enc->width = width;
 		codec->com.ffcodec_enc->height = height;
 
