@@ -40,6 +40,7 @@ static Int zigzag_v[64] = {
 };
 
 /* Inverse normal zigzag */
+#if 0
 static Int zigzag_i[64] =
 {
      0, 1, 8,16, 9, 2, 3,10,
@@ -51,5 +52,6 @@ static Int zigzag_i[64] =
     58,59,52,45,38,31,39,46,
     53,60,61,54,47,55,62,63
 };
+#endif
 
 #endif /* ifndef _ZIGZAG_H_ */
