@@ -128,7 +128,8 @@ static lqt_codec_info_static_t codec_info_divx =
     description: "MPEG4 based video codec",   /* Description            */
     fourccs:     fourccs_divx,
     type:        LQT_CODEC_VIDEO,
-    direction:   LQT_DIRECTION_BOTH,
+    //    direction:   LQT_DIRECTION_BOTH,
+    direction:   LQT_DIRECTION_ENCODE,
     encoding_parameters: encode_parameters_divx,
     decoding_parameters: decode_parameters_divx,
     encoding_colormodels: encoding_colormodels_divx,
