@@ -1,23 +1,23 @@
 /* 
-   rtjpeg.c (C) Justin Schoeman 2002 (justin@suntiger.ee.up.ac.za)
-   Based entirely upon qtpng.c from libquicktime 
-   (http://libquicktime.sf.net).
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-    
-*/
+ * rtjpeg_codec.c (C) Justin Schoeman 2002 (justin@suntiger.ee.up.ac.za)
+ * Based entirely upon qtpng.c from libquicktime 
+ * (http://libquicktime.sf.net).
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *  
+ */
 
 /*
  *  Support for video, which is no multiple of 16 by
@@ -94,7 +94,7 @@ static int decode(quicktime_t *file, unsigned char **row_pointers, int track)
 	result = !quicktime_read_data(file, codec->read_buffer, buffer_size);
 	if(buffer_size > 0) {
 		if(!result)
-			RTjpeg_decompress(codec->decompress_struct, codec->read_buffer, codec->decode_rows);
+                  RTjpeg_decompress(codec->decompress_struct, codec->read_buffer, codec->decode_rows);
 	}
         file_rowspan = file->vtracks[track].row_span ? file->vtracks[track].row_span : file->out_w;
 	if(use_temp) {
