@@ -141,7 +141,12 @@ void destroy_codec_info(lqt_codec_info_t * ptr)
     free(ptr->long_name);
   if(ptr->description)        /* Long name of the codec         */
     free(ptr->description);
+  if(ptr->module_filename)        /* Module filename       */
+    free(ptr->module_filename);
 
+  if(ptr->encoding_colormodels)
+    free(ptr->encoding_colormodels);
+  
   if(ptr->encoding_parameters)
     {
     for(i = 0; i < ptr->num_encoding_parameters; i++)
@@ -235,6 +240,8 @@ copy_codec_info(const lqt_codec_info_t * info)
   int i;
   lqt_codec_info_t * ret = calloc(1, sizeof(lqt_codec_info_t));
 
+  ret->compatibility_flags = info->compatibility_flags;
+    
   if(info->name)
     ret->name = __lqt_strdup(info->name);
   if(info->long_name)
@@ -909,6 +916,8 @@ lqt_create_codec_info(const lqt_codec_info_static_t * template)
   
   ret = calloc(1, sizeof(lqt_codec_info_t));
 
+  ret->compatibility_flags = template->compatibility_flags;
+
   ret->name =        __lqt_strdup(template->name);
   ret->long_name =   __lqt_strdup(template->long_name);
   ret->description = __lqt_strdup(template->description);
@@ -1636,7 +1645,7 @@ void lqt_restore_default_parameters(lqt_codec_info_t * codec_info,
         {
         copy_parameter_value(&(codec_info->decoding_parameters[i].val_default),
                              &(info_from_module->decoding_parameters[i].val_default),
-                             codec_info->encoding_parameters[i].type);
+                             codec_info->decoding_parameters[i].type);
 #ifndef NDEBUG
         //        fprintf(stderr, "Setting decoding parameter %s\n",
         //                codec_info->decoding_parameters[i].name);
