@@ -93,7 +93,7 @@ int quicktime_make_streamable(char *in_path, char *out_path)
 /* moov wasn't the first atom */
 		if(moov_exists > 1)
 		{
-			char *buffer;
+			uint8_t *buffer;
 			int64_t buf_size = 1000000;
 
 			result = 0;
@@ -681,7 +681,8 @@ int quicktime_set_audio_position(quicktime_t *file, int64_t sample, int track)
 		offset = quicktime_sample_to_offset(file, trak, sample);
 		quicktime_set_position(file, offset);
 #else
-                file->atracks->current_position = sample;
+                file->atracks[track].current_position = sample;
+                file->atracks[track].eof = 0;
                 /* Codec will do the rest */
 #endif
 	}
@@ -974,7 +975,7 @@ char* quicktime_video_compressor(quicktime_t *file, int track)
 }
 
 int quicktime_write_audio(quicktime_t *file, 
-	char *audio_buffer, 
+	uint8_t *audio_buffer, 
 	long samples, 
 	int track)
 {
@@ -1060,13 +1061,6 @@ long quicktime_read_audio(quicktime_t *file, char *audio_buffer, long samples, i
 }
 #endif
 
-int quicktime_read_chunk(quicktime_t *file, char *output, int track, int64_t chunk, int64_t byte_start, int64_t byte_len)
-{
-	quicktime_set_position(file, quicktime_chunk_to_offset(file, file->atracks[track].track, chunk) + byte_start);
-	if(quicktime_read_data(file, output, byte_len)) return 0;
-	else
-	return 1;
-}
 
 long quicktime_frame_size(quicktime_t *file, long frame, int track)
 {
@@ -1314,7 +1308,7 @@ int quicktime_read_info(quicktime_t *file)
         int result = 0, got_header = 0;
         int64_t start_position = quicktime_position(file);
         quicktime_atom_t leaf_atom;
-        char avi_avi[4];
+        uint8_t avi_avi[4];
         int got_avi = 0;
         int got_asf = 0;
                                                                                                                   
@@ -1458,7 +1452,7 @@ int quicktime_check_sig(char *path)
         quicktime_t file;
         quicktime_atom_t leaf_atom;
         int result = 0, result1 = 0, result2 = 0;
-        char avi_test[12];
+        uint8_t avi_test[12];
                                                                                                                   
         quicktime_init(&file);
         result = quicktime_file_open(&file, path, 1, 0);
@@ -1604,10 +1598,11 @@ int quicktime_close(quicktime_t *file)
                                                                                                                   
                 if(file->use_avi)
                 {
+#if 0
                         quicktime_atom_t junk_atom;
                         int i;
                         int64_t position = quicktime_position(file);
-                                                                                                                  
+#endif
 // Finalize last header
                         quicktime_finalize_riff(file, file->riff[file->total_riffs - 1]);
                                                                                                                   
@@ -1619,12 +1614,14 @@ int quicktime_close(quicktime_t *file)
                         if(file->total_riffs > 1)
                           quicktime_finalize_indx(file);
                         
+#if 0
 // Pad ending
                         quicktime_set_position(file, position);
                         quicktime_atom_write_header(file, &junk_atom, "JUNK");
                         for(i = 0; i < 0x406; i++)
                                 quicktime_write_int32_le(file, 0);
                         quicktime_atom_write_footer(file, &junk_atom);
+#endif
                 }
                 else
                 {
@@ -1906,11 +1903,17 @@ int lqt_read_audio_chunk(quicktime_t * file, int track,
 
   trak = file->atracks[track].track;
 
-  if(chunk >= file->atracks[track].track->mdia.minf.stbl.stco.total_entries)
+  if(chunk > trak->mdia.minf.stbl.stco.total_entries)
     {
+    /* Read beyond EOF */
+    file->atracks[track].eof = 1;
     return 0;
     }
-  
+#if 0
+  fprintf(stderr, "lqt_read_audio_chunk %d %d\n",
+          chunk,
+          file->atracks[track].track->mdia.minf.stbl.stco.total_entries);
+#endif
   if(!trak->chunk_sizes)
     {
     trak->chunk_sizes = lqt_get_chunk_sizes(file, trak);
@@ -1948,6 +1951,13 @@ int lqt_append_audio_chunk(quicktime_t * file, int track,
 
   trak = file->atracks[track].track;
 
+  if(chunk > trak->mdia.minf.stbl.stco.total_entries)
+    {
+    /* Read beyond EOF */
+    file->atracks[track].eof = 1;
+    return 0;
+    }
+
   if(!trak->chunk_sizes)
     {
     trak->chunk_sizes = lqt_get_chunk_sizes(file, trak);
