@@ -18,12 +18,30 @@ void quicktime_stsd_init_table(quicktime_stsd_t *stsd)
 	}
 }
 
+
+void quicktime_stsd_init_panorama(quicktime_t *file, 
+								quicktime_stsd_t *stsd,
+								int width,
+								int height)
+{
+	quicktime_stsd_table_t *table;
+	quicktime_stsd_init_table(stsd);
+	
+	table = &(stsd->table[0]);
+	table->format[0] = 'p';
+	table->format[1] = 'a';
+	table->format[2] = 'n';
+	table->format[3] = 'o';
+	table->pano.SWidth = width;
+	table->pano.SHeight = height;
+}
+
+
 void quicktime_stsd_init_video(quicktime_t *file, 
 								quicktime_stsd_t *stsd, 
 								int frame_w,
 								int frame_h, 
-								double frame_rate,
-								char *compression)
+                                                                char * compression)
 {
 	quicktime_stsd_table_t *table;
 	quicktime_stsd_init_table(stsd);
@@ -60,6 +78,7 @@ void quicktime_stsd_init_audio(quicktime_t *file,
 	table->channels = channels;
 	table->sample_size = bits;
 	table->sample_rate = sample_rate;
+        fprintf(stderr, "stsd_init_audio: %d\n", bits);
 }
 
 void quicktime_stsd_delete(quicktime_stsd_t *stsd)
@@ -92,7 +111,6 @@ void quicktime_stsd_dump(void *minf_ptr, quicktime_stsd_t *stsd)
 void quicktime_read_stsd(quicktime_t *file, quicktime_minf_t *minf, quicktime_stsd_t *stsd)
 {
 	int i;
-	quicktime_atom_t leaf_atom;
 
 	stsd->version = quicktime_read_char(file);
 	stsd->flags = quicktime_read_int24(file);
