@@ -16,7 +16,8 @@ void quicktime_vmhd_init_video(quicktime_t *file,
 								quicktime_vmhd_t *vmhd, 
 								int frame_w,
 								int frame_h, 
-								double frame_rate)
+                                                                int frame_duration,
+                                                                int timescale)
 {
 }
 
