@@ -30,9 +30,6 @@
 #include <quicktime/lqt.h>
 #include <quicktime/colormodels.h>
 
-/* Define this for floating point audio support */
-// #define USEFLOAT
-
 /* Supported colormodels */
 
 int colormodels[] =
@@ -66,14 +63,17 @@ typedef struct
   {
   quicktime_t * in_file;
   quicktime_t * out_file;
-
-  int64_t num_audio_samples;
+  
   int64_t num_video_frames;
+  int64_t video_duration;
+  
+  int64_t num_audio_samples;
 
   int64_t audio_samples_written;
   int64_t video_frames_written;
   
   unsigned char ** video_buffer;
+
   float   ** audio_buffer_f;
   int16_t ** audio_buffer_i;
   int samples_per_frame;
@@ -86,22 +86,26 @@ typedef struct
   int colormodel;
   int width;
   int height;
-  double framerate;
+
+  int frame_duration;
+  int timescale;
   int samplerate;
   int num_channels;
   int audio_bits;
 
+  /* Progress (0..1) */
+
   float progress;
   } transcode_handle;
 
 static void print_usage()
   {
-  printf("Usage: lqt_transcode [-avi] [-floataudio] [-ac <audio_codec>] [-vc <video_codec>] <in_file> <out_file>\n");
+  printf("Usage: lqt_transcode [-avi] [-floataudio] [-qtvr <obj|pano>] [-qtvr_columns <columns>] [-qtvr_rows <rows>] [-ac <audio_codec>] [-vc <video_codec>] <in_file> <out_file>\n");
   printf("       Transcode <in_file> to <out_file> using <audio_codec> and <video_codec>\n\n");
   printf("       lqt_transcode -lv\n");
-  printf("       List video encoders encoders\n\n");
+  printf("       List video encoders\n\n");
   printf("       lqt_transcode -la\n");
-  printf("       List audio encoders encoders\n");
+  printf("       List audio encoders\n");
   }
 
 static void list_info(lqt_codec_info_t ** info)
@@ -156,9 +160,9 @@ static void list_audio_codecs()
 
 static unsigned char ** alloc_video_buffer(int width, int height, int colormodel)
   {
-  int bytes_per_line;
+  int bytes_per_line = 0;
   int i;
-  int y_size, uv_size;
+  int y_size, uv_size = 0;
   unsigned char ** video_buffer;
   /* Allocate frame buffer */
 
@@ -232,12 +236,14 @@ static int transcode_init(transcode_handle * h,
                           char * video_codec,
                           char * audio_codec,
                           int floataudio,
-                          int use_avi)
+                          int use_avi,
+                          char * qtvr,
+                          int qtvr_rows,
+                          int qtvr_columns)
   {
   lqt_codec_info_t ** codec_info;
   int * colormodels;
   int i;
-  int bytes_per_line;
   
   h->in_file = quicktime_open(in_file, 1, 0);
   if(!h->in_file)
@@ -254,13 +260,17 @@ static int transcode_init(transcode_handle * h,
     
   /* Check for video */
 
-  h->do_video = !!quicktime_video_tracks(h->in_file);
-
+  if(quicktime_video_tracks(h->in_file) &&
+     quicktime_supported_video(h->in_file, 0))
+    h->do_video = 1;
+  
   if(h->do_video)
     {
     h->width     = quicktime_video_width(h->in_file, 0);
     h->height    = quicktime_video_height(h->in_file, 0);
-    h->framerate = quicktime_frame_rate(h->in_file, 0);
+    
+    h->timescale      = lqt_video_time_scale(h->in_file, 0);
+    h->frame_duration = lqt_frame_duration(h->in_file, 0, NULL);
     
     /* Codec info for encoding */
     
@@ -271,11 +281,12 @@ static int transcode_init(transcode_handle * h,
       return 0;
       }
     
+
     /* Set up the output track */
     
     lqt_set_video(h->out_file, 1,
                   h->width, h->height,
-                  h->framerate,
+                  h->frame_duration, h->timescale,
                   codec_info[0]);
     
     /* Get colormodel */
@@ -298,11 +309,13 @@ static int transcode_init(transcode_handle * h,
     lqt_destroy_codec_info(codec_info);
 
     h->num_video_frames = quicktime_video_length(h->in_file, 0);
-
+    h->video_duration = lqt_video_duration(h->in_file, 0);
     }
   /* Check for audio */
-  
-  h->do_audio = !!quicktime_audio_tracks(h->in_file);
+
+  if(quicktime_audio_tracks(h->in_file) &&
+     quicktime_supported_audio(h->in_file, 0))
+    h->do_audio = 1;
   
   if(h->do_audio)
     {
@@ -327,17 +340,35 @@ static int transcode_init(transcode_handle * h,
     lqt_destroy_codec_info(codec_info);
     
     /* Decide about audio frame size */
-#if 1
+#if 0
     if(h->do_video)
       {
-      h->samples_per_frame = (int)(((double)h->samplerate / h->framerate)+0.5);
+      h->samples_per_frame = (int)(((double)h->frame_duration / (double)h->timescale)+0.5);
       /* Avoid too odd numbers */
       h->samples_per_frame = 16 * ((h->samples_per_frame + 15) / 16);
       }
     else
       h->samples_per_frame = 4096;
 #else
-    h->samples_per_frame = 8192;
+
+    /* Ok, we must take care about the audio frame size.
+       The sample count, we pass to encode_audio() directly affects interleaving.
+       Too many audio chunks make decoding inefficient, too few make seeking
+       take longer becauuse many samples inside a chunk have to be skipped.
+       
+       On the other hand, having too many audio chunks also slows down seeking...
+
+       Ok, then lets just take half a second and see how it works :-)
+
+       On a 25 fps system this means, that one audio chunks comes after an average of
+       12.5 video frames. This is roughly what we see in files created with other
+       Software
+    */
+    
+    h->samples_per_frame = h->samplerate / 2;
+    /* Avoid too odd numbers */
+    h->samples_per_frame = 16 * ((h->samples_per_frame + 15) / 16);
+
 #endif
     /* Allocate output buffer */
 
@@ -358,6 +389,24 @@ static int transcode_init(transcode_handle * h,
     h->num_audio_samples = quicktime_audio_length(h->in_file, 0);
     }
 
+    if (qtvr) {
+	if(strncmp(qtvr,"obj", 3) == 0) {
+	    lqt_qtvr_set_type(h->out_file, QTVR_OBJ, 0 , 0, 0, 0, 0);
+	}
+	
+	if(strncmp(qtvr,"pano", 4) == 0) {
+	    lqt_qtvr_set_type(h->out_file, QTVR_PAN, qtvr_columns * h->height, qtvr_rows * h->width, h->frame_duration, h->timescale, 0);
+	}
+	
+	if(qtvr_columns) {
+	    lqt_qtvr_set_columns(h->out_file, (short)qtvr_columns);
+	}
+	
+	if(qtvr_rows) {
+	    lqt_qtvr_set_rows(h->out_file, (short)qtvr_rows);
+	}
+    }
+    
   if(use_avi)
     quicktime_set_avi(h->out_file, 1);
   return 1;
@@ -370,10 +419,14 @@ static int transcode_iteration(transcode_handle * h)
   int num_samples;
   int do_audio = 0;
   float progress;
+  int64_t frame_time;
+
+  //  fprintf(stderr, "Transcode iteration\n");
+  
   if(h->do_audio && h->do_video)
     {
     audio_time = (float)(h->audio_samples_written)/(float)(h->samplerate);
-    video_time = (float)(h->video_frames_written)/h->framerate;
+    video_time = (float)(h->video_frames_written * h->frame_duration)/h->timescale;
 
     //    fprintf(stderr, "Transcode time: %f %f\n", audio_time, video_time);
     
@@ -389,26 +442,26 @@ static int transcode_iteration(transcode_handle * h)
 
   if(do_audio)
     {
-    /* Last frame needs special attention */
-    if(h->audio_samples_written + h->samples_per_frame >= h->num_audio_samples)
-      num_samples = h->num_audio_samples - h->audio_samples_written;
-    else
-      num_samples = h->samples_per_frame;
-
-    lqt_decode_audio(h->in_file, h->audio_buffer_i, h->audio_buffer_f, num_samples);
+    //    lqt_decode_audio(h->in_file, h->audio_buffer_i, h->audio_buffer_f, h->samples_per_frame);
+    lqt_decode_audio_track(h->in_file, h->audio_buffer_i, h->audio_buffer_f, h->samples_per_frame, 0);
+    num_samples = lqt_last_audio_position(h->in_file, 0) - h->audio_samples_written;
+    
     quicktime_encode_audio(h->out_file, h->audio_buffer_i, h->audio_buffer_f, num_samples);
     h->audio_samples_written += num_samples;
 
-    if(h->audio_samples_written >= h->num_audio_samples)
+    if(num_samples < h->samples_per_frame)
       h->do_audio = 0;
     progress = (float)(h->audio_samples_written)/(float)(h->num_audio_samples);
+
+    //    fprintf(stderr, "Audio iteration %lld %d %d\n", h->audio_samples_written, num_samples, h->samples_per_frame);
     }
   /* Video Iteration */
   else
     {
+    frame_time = lqt_frame_time(h->in_file, 0);
     lqt_decode_video(h->in_file, h->video_buffer, 0);
-    quicktime_encode_video(h->out_file, h->video_buffer, 0);
-
+    lqt_encode_video(h->out_file, h->video_buffer, 0, frame_time);
+    
     h->video_frames_written++;
     if(h->video_frames_written >= h->num_video_frames)
       h->do_video = 0;
@@ -421,6 +474,7 @@ static int transcode_iteration(transcode_handle * h)
 
   if(progress > h->progress)
     h->progress = progress;
+  //  fprintf(stderr, "Progress: %f\n", h->progress);
   return 1;
   }
 
@@ -436,6 +490,9 @@ int main(int argc, char ** argv)
   char * out_file = (char*)0;
   char * video_codec = (char*)0;
   char * audio_codec = (char*)0;
+  char * qtvr = (char*)0;
+  unsigned short qtvr_rows = 0;
+  unsigned short qtvr_columns = 0;
   int i, j;
   int use_avi = 0, floataudio = 0;
   transcode_handle handle;
@@ -477,13 +534,25 @@ int main(int argc, char ** argv)
           use_avi = 1;
         else if(!strcmp(argv[i], "-floataudio"))
           floataudio = 1;
+        else if(!strcmp(argv[i], "-qtvr")) {
+          qtvr = argv[i+1];
+	  i++;
+	  }
+	else if(!strcmp(argv[i], "-qtvr_rows")) {
+          qtvr_rows = atoi(argv[i+1]);
+	  i++;
+	  }
+	else if(!strcmp(argv[i], "-qtvr_columns")) {
+          qtvr_columns = atoi(argv[i+1]);
+	  i++;
+	  }
         }
       in_file = argv[argc-2];
       out_file = argv[argc-1];
     }
   
   if(!transcode_init(&handle, in_file, out_file, video_codec, audio_codec,
-                     floataudio, use_avi))
+                     floataudio, use_avi, qtvr, qtvr_rows, qtvr_columns))
     {
     return 0;
     }
